<div class="header">
	<h1>{{ 'FEEDS.TITLE' | translate }}</h1>
</div>

<div id="feeds" class="content" ng-controller="FeedCtrl" ng-init="init()">
	<div class="pure-g bandeau">
		<div class="pure-u-8-24"><a href="#/config">{{ 'MENU.SETTINGS' | translate }}</a></div>
		<div class="pure-u-8-24"><a href="#/feed" class="menu-selected">{{ 'MENU.FEEDS' | translate }}</a></div>
		<div class="pure-u-8-24"><a ng-href="{{ pathPrefix }}/logout/">{{ 'MENU.LOG_OUT' | translate }}</a></div>
	</div>

	<div>
		<form class="zenform centered">
			<a href="#/feed/add"><input type="button" value="{{ 'FEEDS.NEW' | translate }}" /></a>
			<input type="button" class="button-grey" value="{{ 'FEEDS.IMPORT' | translate }}" />
			<input type="button" class="button-grey" value="{{ 'FEEDS.EXPORT' | translate }}" />
		</form>

		<div ng-repeat="feed in feeds | orderBy:sortOrder" class="grid-row pure-g-r">
			<div class="pure-u-1-24">
				<img height="24px" width="24px" src="{{ feed.favicon_url }}" alt="[i]" />
			</div>
			<div class="pure-u-2-24 entry-title">
				<div class="tag">{{ feed.nb_of_entries }}</div>
			</div>
			<div class="pure-u-18-24 indieflower">
				<a href="#/feed/edit/{{ feed.id }}">{{ feed.title }}</a>
			</div>
			<!-- <div class="pure-u-1-24 entry-title"><a href="#/feed/edit/{{ feed.id }}">⚙</a></div> -->
			<div class="pure-u-3-24 entry-title"><a href="" ng-click="deleteFeed(feed.id)">× supprimer</a></div>
			<!-- <div class="pure-u-1-24 entry-title"><a href="">+</a></div> -->
		</div>
	</div>

	<form class="zenform centered">
		<br />
		<input type="button" class="button-grey" ng-click="refetch()" value="{{ 'CONFIG.REFETCH' | translate }}" />
	</form>
</div>
