{% extends "base.html" %}

{% block body %}

	<div class="header">
    	<h1>{{ entry.title }}</h1>
	</div>

	<div id="entry" class="content">
		<div class="pure-g bandeau">
			<div class="pure-u-1-24">
				<a href="{{ url_for('index') }}">&#9775;</a>
			</div>
			<div class="pure-u-8-24">
				<a href="{{ url_for('feed_view', feed_id=entry.feed_id) }}">
					← {{ _('Retour au flux') }}
				</a>
			</div>
			<div class="pure-u-8-24">
				<a href="{{ entry.link }}" id="article-link">{{ _('Article') }}</a>
			</div>
			<div class="pure-u-7-24">
				<a href="{{ entry.url }}">({{ _('Permalien') }})</a>
			</div>
		</div>

	{{ entry.content|safe }}
	</div>
{% endblock %}
