{% extends "base.html" %}

{% block body %}

	<div class="header">
    <h1>Zenfeed.</h1>
	</div>

	<div id="feeds" class="content">
	{% for feed in feeds %}
		<div class="grid-row pure-g-r{{ ' has-news' if feed.has_news }}"
			 data-url="{{ url_for('feed_view', feed_id=feed.id) }}">
			<div class="pure-u-1-24">
				<img height="24px" width="24px"
				 src="{{ url_for('get_favicon', favicon=feed.favicon_path) }}" alt="[i]" />
			</div>
			<div class="pure-u-5-24 feed-title navlink">
				<a href="{{ url_for('feed_view', feed_id=feed.id) }}">{{ feed.title }}</a>
			</div>
			<div class="pure-u-15-24 entry-title">
				{{ feed.last_entry().title }}
			</div>
			<div class="pure-u-3-24 time-ago">
				{{ feed.updated | humanize_date }}
			</div>
		</div>
	{% endfor %}
	</div>

{% endblock %}
