{% extends "base.html" %}

{% block body %}

	<div class="header">
    <h1>Zenfeed.</h1>
	</div>

	<div class="content">
		<form id="login-form" class="zenform" method="post" action="{{ url_for('login', next=next_page) }}">
			<input type="password" name="pw" size="25" placeholder="{{ _('Mot de passe') }}" autofocus />
			<input type="submit" value="{{ _('Se connecter') }}" />
		</form>
	</div>

{% endblock %}
{% block js %}{% endblock %}
