{% extends "base.html" %}

{% block title %}Zenfeed − {{ _('Administration') }}.{% endblock %}

{% block body %}
<div ng-app="zenfeed">
	<div ng-view></div>
</div>
{% endblock %}

{% block js %}
	<script src="//cdnjs.cloudflare.com/ajax/libs/angular.js/1.2.16/angular.min.js"></script>
	<script src="//cdnjs.cloudflare.com/ajax/libs/angular.js/1.2.16/angular-route.min.js"></script>
	<script src="//cdnjs.cloudflare.com/ajax/libs/bower-angular-translate/2.0.1/angular-translate.min.js"></script>
	<script>
		var app = angular.module('zenfeed', ['ngRoute', 'pascalprecht.translate']);
		app.constant('pathPrefix', '{{ path_prefix }}');
	</script>
	<script src="{{ url_for('static', filename='js/admin/translations.js') }}"></script>
	<script src="{{ url_for('static', filename='js/admin/routes.js') }}"></script>
	<script src="{{ url_for('static', filename='js/admin/services.js') }}"></script>
	<script src="{{ url_for('static', filename='js/admin/controllers.js') }}"></script>
{% endblock %}
